@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief RRDA 形式データのエンコード
+  \brief RRDA リソースのエンコード
 
   \author Satofumi KAMIMURA
 
@@ -17,6 +17,9 @@
 class RrdaResource;
 
 
+/*!
+  \brief RRDA リソースのエンコード
+*/
 class RrdaEncoder {
   RrdaEncoder(void);
   RrdaEncoder(const RrdaEncoder& rhs);
@@ -26,6 +29,13 @@ class RrdaEncoder {
   std::auto_ptr<pImpl> pimpl;
 
 public:
+
+  /*!
+    \brief コンストラクタ
+
+    \param fileName [i] リソースファイル
+    \param key [i] キー
+  */
   explicit RrdaEncoder(const char* fileName, const char* key);
   ~RrdaEncoder(void);
 
@@ -42,8 +52,6 @@ public:
     \param resource_name [i] リソース名
 
     \return RrdaResouce オブジェクト
-
-    !!! auto_ptr(), shared_ptr() を使った例を記述する
   */
   RrdaResource* getResource(const char* resource_name);
 };
