@@ -13,6 +13,9 @@
 #include <memory>
 
 
+/*!
+  \brief RRDA のリソース管理
+*/
 class RrdaResource {
 
   RrdaResource(void);
@@ -23,6 +26,13 @@ class RrdaResource {
   std::auto_ptr<pImpl> pimpl;
 
  public:
+
+  /*!
+    \brief コンストラクタ
+
+    \param fin [i] 圧縮ファイル位置の読み出しストリーム
+    \param size [i] 圧縮ファイルのサイズ
+  */
   explicit RrdaResource(std::ifstream& fin, size_t size);
   ~RrdaResource(void);
 
