@@ -26,27 +26,31 @@ class ThemeClockDraw : public QWidget {
   std::auto_ptr<pImpl> pimpl;
 
 protected:
+  /*!
+    \brief 描画イベント処理
+
+    \param event [i/o] イベント
+  */
   void paintEvent(QPaintEvent* event);
 
 public:
   /*!
     \brief コンストラクタ
 
-    \param theme_file [i] テーマファイル名
     \param parent [i] 親ウィジット
   */
   ThemeClockDraw(QWidget* parent = 0);
   ~ThemeClockDraw(void);
 
-  bool loadThemeFile(const QString& theme_file);
-
   /*!
-    \brief テーマがロードされたかを返す
+    \brief テーマファイルの読み出し
+
+    \param theme_file [i] テーマファイル
 
     \retval true 成功
-    \retval false 失敗
+    \retval エラー
   */
-  bool isThemeLoaded(void);
+  bool loadThemeFile(const QString& theme_file, const char* key = "LMTC");
 
   /*!
     \brief テーマファイル名を返す
@@ -62,6 +66,11 @@ public:
   */
   void redraw(void);
 
+  /*!
+    \brief 透過領域の取得
+
+    \return 透過領域
+  */
   QRegion* getRegion(void);
 
 signals:
