@@ -5,6 +5,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo 指定した拡張子のファイルのみ、ドラッグ可能にする
 */
 
 #include <QtGui>
@@ -43,6 +45,7 @@ struct ThemeClockWidget::pImpl {
     parent->setAcceptDrops(true);
   }
 
+
   // 次に秒針が動くまでのミリ秒だけ待機
   void startClock(ThemeClockWidget* parent) {
 
@@ -52,6 +55,8 @@ struct ThemeClockWidget::pImpl {
     QTimer::singleShot(1000 - current_time.msec(), parent, SLOT(redraw()));
   }
 
+
+  // 再描画
   void redraw(ThemeClockWidget* parent) {
     static_cast<void>(parent);
 
@@ -63,39 +68,47 @@ struct ThemeClockWidget::pImpl {
     draw_widget_->redraw();
   }
 
-  bool tryLoadTheme(const QString& theme_file) {
 
-    bool ret = false;
+  // テーマファイルの読み出しを試行
+  bool tryLoadTheme(const QString& theme_file, ThemeClockWidget* parent) {
 
     // テーマの読み出し
-    if (loadThemeFile(theme_file)) {
+    if (loadThemeFile(theme_file, parent)) {
       // 今回指定されたテーマ
-      theme_file_ = theme_file;
-      ret = true;
+      return true;
 
-    } else if (loadThemeFile(pre_theme_file_)) {
+    } else if (loadThemeFile(pre_theme_file_, parent)) {
       // 前回利用したテーマ
-      theme_file_ = pre_theme_file_;
-      ret = true;
+      return true;
 
     } else {
       // テーマのドロップを促すフォームを作成
-      loadThemeFile("");
+      loadThemeFile("", parent);
+      return false;
+    }
+  }
+
+
+  // テーマファイルの読み出し
+  bool loadThemeFile(const QString& theme_file, ThemeClockWidget* parent) {
+
+    if (! draw_widget_->loadThemeFile(theme_file)) {
+      return false;
     }
 
-    return ret;
+    theme_file_ = theme_file;
+    parent->resize(draw_widget_->size());
+    return true;
   }
 
-  bool loadThemeFile(const QString& theme_file) {
-
-    draw_widget_->loadThemeFile(theme_file);
-    return draw_widget_->isThemeLoaded();
-  }
 
+  // テーマファイル名の取得
   QString getThemeFile(void) {
     return draw_widget_->getThemeFile();
   }
 
+
+  // 設定の読み出し
   void readSettings(bool position_specified, ThemeClockWidget* parent) {
 
     QSettings settings("Hyakuren Soft LTD.", "qtmclock");
@@ -108,6 +121,8 @@ struct ThemeClockWidget::pImpl {
     }
   }
 
+
+  // 設定の書き込み
   void writeSettings(ThemeClockWidget* parent) {
 
     QSettings settings("Hyakuren Soft LTD.", "qtmclock");
@@ -120,6 +135,8 @@ struct ThemeClockWidget::pImpl {
                                         size.width(), size.height()));
   }
 
+
+  // 右クリックメニューの初期化
   void initializeMenu(ThemeClockWidget* parent) {
 
     QAction* quit_action = new QAction(QAction::tr("E&xit"), parent);
@@ -141,7 +158,7 @@ ThemeClockWidget::ThemeClockWidget(const QString& theme_file,
   pimpl->readSettings(position_specified, this);
 
   // テーマの読み出し
-  pimpl->tryLoadTheme(theme_file);
+  pimpl->tryLoadTheme(theme_file, this);
   resize(pimpl->draw_widget_->size());
 
   // フォームの初期化
@@ -162,11 +179,13 @@ ThemeClockWidget::~ThemeClockWidget(void) {
 }
 
 
+// 再描画
 void ThemeClockWidget::redraw(void) {
   pimpl->redraw(this);
 }
 
 
+// リサイズ
 void ThemeClockWidget::resizeEvent(QResizeEvent* event) {
   static_cast<void>(event);
 
@@ -181,6 +200,7 @@ void ThemeClockWidget::resizeEvent(QResizeEvent* event) {
 }
 
 
+// 左クリックでのフォーム移動用
 void ThemeClockWidget::mousePressEvent(QMouseEvent* event) {
 
   if (event->button() == Qt::LeftButton) {
@@ -190,6 +210,7 @@ void ThemeClockWidget::mousePressEvent(QMouseEvent* event) {
 }
 
 
+// 左クリックでのフォーム移動
 void ThemeClockWidget::mouseMoveEvent(QMouseEvent* event) {
 
   if (event->buttons() & Qt::LeftButton) {
@@ -199,6 +220,7 @@ void ThemeClockWidget::mouseMoveEvent(QMouseEvent* event) {
 }
 
 
+// テーマのリロード用
 void ThemeClockWidget::dragEnterEvent(QDragEnterEvent* event) {
 
   setBackgroundRole(QPalette::Highlight);
@@ -206,16 +228,17 @@ void ThemeClockWidget::dragEnterEvent(QDragEnterEvent* event) {
 }
 
 
+// テーマのリロード用
 void ThemeClockWidget::dragMoveEvent(QDragEnterEvent* event) {
 
-  event->acceptProposedAction(); static_cast<void>(event);
+  event->acceptProposedAction();
 }
 
 
+// テーマのリロード
 void ThemeClockWidget::dropEvent(QDropEvent* event) {
 
   const QMimeData* mime_data = event->mimeData();
-
   if (! mime_data->hasUrls()) {
     return;
   }
@@ -233,11 +256,7 @@ void ThemeClockWidget::dropEvent(QDropEvent* event) {
       QTextCodec* codec = QTextCodec::codecForName("Shift-JIS");
       path = codec->fromUnicode(path);
     }
-    if (pimpl->draw_widget_->loadThemeFile(path)) {
-
-      // !!! 本来の代入処理とこのあたりの代入処理とを、くくるべき
-      pimpl->theme_file_ = path;
-      resize(pimpl->draw_widget_->size());
+    if (pimpl->loadThemeFile(path, this)) {
       return;
 
     } else {
