@@ -14,7 +14,7 @@
         <translation type="obsolete">終了&amp;x</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="119"/>
+        <location filename="ThemeClockWidget.cpp" line="126"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl-Q</translation>
     </message>
@@ -22,7 +22,7 @@
 <context>
     <name>QAction</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="118"/>
+        <location filename="ThemeClockWidget.cpp" line="125"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;x)</translation>
     </message>
@@ -30,9 +30,22 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="44"/>
+        <location filename="ThemeClockDraw.cpp" line="126"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
     </message>
 </context>
+<context>
+    <name>ThemeClockWidget</name>
+    <message>
+        <location filename="ThemeClockWidget.cpp" line="245"/>
+        <source>qtmclock</source>
+        <translation>qtmclock</translation>
+    </message>
+    <message>
+        <location filename="ThemeClockWidget.cpp" line="246"/>
+        <source>%1 is not correct theme file.</source>
+        <translation>%1 はテーマファイルではありません。</translation>
+    </message>
+</context>
 </TS>
